/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataUpcloudManagedDatabaseOpensearchIndicesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices#id DataUpcloudManagedDatabaseOpensearchIndices#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Service's UUID for which these indices belongs to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices#service DataUpcloudManagedDatabaseOpensearchIndices#service}
    */
    readonly service: string;
    /**
    * indices block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices#indices DataUpcloudManagedDatabaseOpensearchIndices#indices}
    */
    readonly indices?: DataUpcloudManagedDatabaseOpensearchIndicesIndices[] | cdktf.IResolvable;
}
export interface DataUpcloudManagedDatabaseOpensearchIndicesIndices {
}
export declare function dataUpcloudManagedDatabaseOpensearchIndicesIndicesToTerraform(struct?: DataUpcloudManagedDatabaseOpensearchIndicesIndices | cdktf.IResolvable): any;
export declare function dataUpcloudManagedDatabaseOpensearchIndicesIndicesToHclTerraform(struct?: DataUpcloudManagedDatabaseOpensearchIndicesIndices | cdktf.IResolvable): any;
export declare class DataUpcloudManagedDatabaseOpensearchIndicesIndicesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataUpcloudManagedDatabaseOpensearchIndicesIndices | cdktf.IResolvable | undefined;
    set internalValue(value: DataUpcloudManagedDatabaseOpensearchIndicesIndices | cdktf.IResolvable | undefined);
    get createTime(): string;
    get docs(): number;
    get health(): string;
    get indexName(): string;
    get numberOfReplicas(): number;
    get numberOfShards(): number;
    get readOnlyAllowDelete(): cdktf.IResolvable;
    get size(): number;
    get status(): string;
}
export declare class DataUpcloudManagedDatabaseOpensearchIndicesIndicesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataUpcloudManagedDatabaseOpensearchIndicesIndices[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataUpcloudManagedDatabaseOpensearchIndicesIndicesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices upcloud_managed_database_opensearch_indices}
*/
export declare class DataUpcloudManagedDatabaseOpensearchIndices extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "upcloud_managed_database_opensearch_indices";
    /**
    * Generates CDKTF code for importing a DataUpcloudManagedDatabaseOpensearchIndices resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataUpcloudManagedDatabaseOpensearchIndices to import
    * @param importFromId The id of the existing DataUpcloudManagedDatabaseOpensearchIndices that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataUpcloudManagedDatabaseOpensearchIndices to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_opensearch_indices upcloud_managed_database_opensearch_indices} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataUpcloudManagedDatabaseOpensearchIndicesConfig
    */
    constructor(scope: Construct, id: string, config: DataUpcloudManagedDatabaseOpensearchIndicesConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
    private _indices;
    get indices(): DataUpcloudManagedDatabaseOpensearchIndicesIndicesList;
    putIndices(value: DataUpcloudManagedDatabaseOpensearchIndicesIndices[] | cdktf.IResolvable): void;
    resetIndices(): void;
    get indicesInput(): cdktf.IResolvable | DataUpcloudManagedDatabaseOpensearchIndicesIndices[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
