/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataUpcloudManagedDatabaseRedisSessionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#id DataUpcloudManagedDatabaseRedisSessions#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Number of entries to receive at most.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#limit DataUpcloudManagedDatabaseRedisSessions#limit}
    */
    readonly limit?: number;
    /**
    * Offset for retrieved results based on sort order.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#offset DataUpcloudManagedDatabaseRedisSessions#offset}
    */
    readonly offset?: number;
    /**
    * Order by session field and sort retrieved results. Limited variables can be used for ordering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#order DataUpcloudManagedDatabaseRedisSessions#order}
    */
    readonly order?: string;
    /**
    * Service's UUID for which these sessions belongs to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#service DataUpcloudManagedDatabaseRedisSessions#service}
    */
    readonly service: string;
    /**
    * sessions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#sessions DataUpcloudManagedDatabaseRedisSessions#sessions}
    */
    readonly sessions?: DataUpcloudManagedDatabaseRedisSessionsSessions[] | cdktf.IResolvable;
}
export interface DataUpcloudManagedDatabaseRedisSessionsSessions {
}
export declare function dataUpcloudManagedDatabaseRedisSessionsSessionsToTerraform(struct?: DataUpcloudManagedDatabaseRedisSessionsSessions | cdktf.IResolvable): any;
export declare function dataUpcloudManagedDatabaseRedisSessionsSessionsToHclTerraform(struct?: DataUpcloudManagedDatabaseRedisSessionsSessions | cdktf.IResolvable): any;
export declare class DataUpcloudManagedDatabaseRedisSessionsSessionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataUpcloudManagedDatabaseRedisSessionsSessions | cdktf.IResolvable | undefined;
    set internalValue(value: DataUpcloudManagedDatabaseRedisSessionsSessions | cdktf.IResolvable | undefined);
    get activeChannelSubscriptions(): number;
    get activeDatabase(): string;
    get activePatternMatchingChannelSubscriptions(): number;
    get applicationName(): string;
    get clientAddr(): string;
    get connectionAge(): number;
    get connectionIdle(): number;
    get flags(): string[];
    get flagsRaw(): string;
    get id(): string;
    get multiExecCommands(): number;
    get outputBuffer(): number;
    get outputBufferMemory(): number;
    get outputListLength(): number;
    get query(): string;
    get queryBuffer(): number;
    get queryBufferFree(): number;
}
export declare class DataUpcloudManagedDatabaseRedisSessionsSessionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataUpcloudManagedDatabaseRedisSessionsSessions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataUpcloudManagedDatabaseRedisSessionsSessionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions upcloud_managed_database_redis_sessions}
*/
export declare class DataUpcloudManagedDatabaseRedisSessions extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "upcloud_managed_database_redis_sessions";
    /**
    * Generates CDKTF code for importing a DataUpcloudManagedDatabaseRedisSessions resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataUpcloudManagedDatabaseRedisSessions to import
    * @param importFromId The id of the existing DataUpcloudManagedDatabaseRedisSessions that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataUpcloudManagedDatabaseRedisSessions to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/data-sources/managed_database_redis_sessions upcloud_managed_database_redis_sessions} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataUpcloudManagedDatabaseRedisSessionsConfig
    */
    constructor(scope: Construct, id: string, config: DataUpcloudManagedDatabaseRedisSessionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    resetLimit(): void;
    get limitInput(): number | undefined;
    private _offset?;
    get offset(): number;
    set offset(value: number);
    resetOffset(): void;
    get offsetInput(): number | undefined;
    private _order?;
    get order(): string;
    set order(value: string);
    resetOrder(): void;
    get orderInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
    private _sessions;
    get sessions(): DataUpcloudManagedDatabaseRedisSessionsSessionsList;
    putSessions(value: DataUpcloudManagedDatabaseRedisSessionsSessions[] | cdktf.IResolvable): void;
    resetSessions(): void;
    get sessionsInput(): cdktf.IResolvable | DataUpcloudManagedDatabaseRedisSessionsSessions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
