/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GatewayConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the upcloud_gateway resource to which the connection belongs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#gateway GatewayConnection#gateway}
    */
    readonly gateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#id GatewayConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the connection, should be unique within the gateway.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#name GatewayConnection#name}
    */
    readonly name: string;
    /**
    * The type of the connection; currently the only supported type is 'ipsec'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#type GatewayConnection#type}
    */
    readonly type?: string;
    /**
    * local_route block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#local_route GatewayConnection#local_route}
    */
    readonly localRoute?: GatewayConnectionLocalRoute[] | cdktf.IResolvable;
    /**
    * remote_route block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#remote_route GatewayConnection#remote_route}
    */
    readonly remoteRoute?: GatewayConnectionRemoteRoute[] | cdktf.IResolvable;
}
export interface GatewayConnectionLocalRoute {
    /**
    * Name of the route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#name GatewayConnection#name}
    */
    readonly name: string;
    /**
    * Destination prefix of the route; needs to be a valid IPv4 prefix
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#static_network GatewayConnection#static_network}
    */
    readonly staticNetwork: string;
    /**
    * Type of route; currently the only supported type is 'static'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#type GatewayConnection#type}
    */
    readonly type?: string;
}
export declare function gatewayConnectionLocalRouteToTerraform(struct?: GatewayConnectionLocalRoute | cdktf.IResolvable): any;
export declare function gatewayConnectionLocalRouteToHclTerraform(struct?: GatewayConnectionLocalRoute | cdktf.IResolvable): any;
export declare class GatewayConnectionLocalRouteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GatewayConnectionLocalRoute | cdktf.IResolvable | undefined;
    set internalValue(value: GatewayConnectionLocalRoute | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _staticNetwork?;
    get staticNetwork(): string;
    set staticNetwork(value: string);
    get staticNetworkInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GatewayConnectionLocalRouteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GatewayConnectionLocalRoute[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GatewayConnectionLocalRouteOutputReference;
}
export interface GatewayConnectionRemoteRoute {
    /**
    * Name of the route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#name GatewayConnection#name}
    */
    readonly name: string;
    /**
    * Destination prefix of the route; needs to be a valid IPv4 prefix
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#static_network GatewayConnection#static_network}
    */
    readonly staticNetwork: string;
    /**
    * Type of route; currently the only supported type is 'static'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#type GatewayConnection#type}
    */
    readonly type?: string;
}
export declare function gatewayConnectionRemoteRouteToTerraform(struct?: GatewayConnectionRemoteRoute | cdktf.IResolvable): any;
export declare function gatewayConnectionRemoteRouteToHclTerraform(struct?: GatewayConnectionRemoteRoute | cdktf.IResolvable): any;
export declare class GatewayConnectionRemoteRouteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GatewayConnectionRemoteRoute | cdktf.IResolvable | undefined;
    set internalValue(value: GatewayConnectionRemoteRoute | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _staticNetwork?;
    get staticNetwork(): string;
    set staticNetwork(value: string);
    get staticNetworkInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GatewayConnectionRemoteRouteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GatewayConnectionRemoteRoute[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GatewayConnectionRemoteRouteOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection upcloud_gateway_connection}
*/
export declare class GatewayConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_gateway_connection";
    /**
    * Generates CDKTF code for importing a GatewayConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GatewayConnection to import
    * @param importFromId The id of the existing GatewayConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GatewayConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/gateway_connection upcloud_gateway_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GatewayConnectionConfig
    */
    constructor(scope: Construct, id: string, config: GatewayConnectionConfig);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get tunnels(): string[];
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    get uuid(): string;
    private _localRoute;
    get localRoute(): GatewayConnectionLocalRouteList;
    putLocalRoute(value: GatewayConnectionLocalRoute[] | cdktf.IResolvable): void;
    resetLocalRoute(): void;
    get localRouteInput(): cdktf.IResolvable | GatewayConnectionLocalRoute[] | undefined;
    private _remoteRoute;
    get remoteRoute(): GatewayConnectionRemoteRouteList;
    putRemoteRoute(value: GatewayConnectionRemoteRoute[] | cdktf.IResolvable): void;
    resetRemoteRoute(): void;
    get remoteRouteInput(): cdktf.IResolvable | GatewayConnectionRemoteRoute[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
