/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkPeeringConfig extends cdktf.TerraformMetaArguments {
    /**
    * Configured status of the network peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#configured_status NetworkPeering#configured_status}
    */
    readonly configuredStatus?: string;
    /**
    * Key-value pairs to classify the network peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#labels NetworkPeering#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the network peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#name NetworkPeering#name}
    */
    readonly name: string;
    /**
    * network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#network NetworkPeering#network}
    */
    readonly network?: NetworkPeeringNetwork[] | cdktf.IResolvable;
    /**
    * peer_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#peer_network NetworkPeering#peer_network}
    */
    readonly peerNetwork?: NetworkPeeringPeerNetwork[] | cdktf.IResolvable;
}
export interface NetworkPeeringNetwork {
    /**
    * The UUID of the network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#uuid NetworkPeering#uuid}
    */
    readonly uuid: string;
}
export declare function networkPeeringNetworkToTerraform(struct?: NetworkPeeringNetwork | cdktf.IResolvable): any;
export declare function networkPeeringNetworkToHclTerraform(struct?: NetworkPeeringNetwork | cdktf.IResolvable): any;
export declare class NetworkPeeringNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkPeeringNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkPeeringNetwork | cdktf.IResolvable | undefined);
    private _uuid?;
    get uuid(): string;
    set uuid(value: string);
    get uuidInput(): string | undefined;
}
export declare class NetworkPeeringNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkPeeringNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkPeeringNetworkOutputReference;
}
export interface NetworkPeeringPeerNetwork {
    /**
    * The UUID of the network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#uuid NetworkPeering#uuid}
    */
    readonly uuid: string;
}
export declare function networkPeeringPeerNetworkToTerraform(struct?: NetworkPeeringPeerNetwork | cdktf.IResolvable): any;
export declare function networkPeeringPeerNetworkToHclTerraform(struct?: NetworkPeeringPeerNetwork | cdktf.IResolvable): any;
export declare class NetworkPeeringPeerNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkPeeringPeerNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkPeeringPeerNetwork | cdktf.IResolvable | undefined);
    private _uuid?;
    get uuid(): string;
    set uuid(value: string);
    get uuidInput(): string | undefined;
}
export declare class NetworkPeeringPeerNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkPeeringPeerNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkPeeringPeerNetworkOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering upcloud_network_peering}
*/
export declare class NetworkPeering extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_network_peering";
    /**
    * Generates CDKTF code for importing a NetworkPeering resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkPeering to import
    * @param importFromId The id of the existing NetworkPeering that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkPeering to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/network_peering upcloud_network_peering} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkPeeringConfig
    */
    constructor(scope: Construct, id: string, config: NetworkPeeringConfig);
    private _configuredStatus?;
    get configuredStatus(): string;
    set configuredStatus(value: string);
    resetConfiguredStatus(): void;
    get configuredStatusInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _network;
    get network(): NetworkPeeringNetworkList;
    putNetwork(value: NetworkPeeringNetwork[] | cdktf.IResolvable): void;
    resetNetwork(): void;
    get networkInput(): cdktf.IResolvable | NetworkPeeringNetwork[] | undefined;
    private _peerNetwork;
    get peerNetwork(): NetworkPeeringPeerNetworkList;
    putPeerNetwork(value: NetworkPeeringPeerNetwork[] | cdktf.IResolvable): void;
    resetPeerNetwork(): void;
    get peerNetworkInput(): cdktf.IResolvable | NetworkPeeringPeerNetwork[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
