/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RouterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Key-value pairs to classify the router.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#labels Router#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the router.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#name Router#name}
    */
    readonly name: string;
    /**
    * static_route block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#static_route Router#static_route}
    */
    readonly staticRoute?: RouterStaticRoute[] | cdktf.IResolvable;
}
export interface RouterStaticRoute {
    /**
    * Name or description of the route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#name Router#name}
    */
    readonly name?: string;
    /**
    * Next hop address. NOTE: For static route to be active the next hop has to be an address of a reachable running Cloud Server in one of the Private Networks attached to the router.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#nexthop Router#nexthop}
    */
    readonly nexthop: string;
    /**
    * Destination prefix of the route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#route Router#route}
    */
    readonly route: string;
}
export declare function routerStaticRouteToTerraform(struct?: RouterStaticRoute | cdktf.IResolvable): any;
export declare function routerStaticRouteToHclTerraform(struct?: RouterStaticRoute | cdktf.IResolvable): any;
export declare class RouterStaticRouteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RouterStaticRoute | cdktf.IResolvable | undefined;
    set internalValue(value: RouterStaticRoute | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _nexthop?;
    get nexthop(): string;
    set nexthop(value: string);
    get nexthopInput(): string | undefined;
    private _route?;
    get route(): string;
    set route(value: string);
    get routeInput(): string | undefined;
}
export declare class RouterStaticRouteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RouterStaticRoute[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RouterStaticRouteOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router upcloud_router}
*/
export declare class Router extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_router";
    /**
    * Generates CDKTF code for importing a Router resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Router to import
    * @param importFromId The id of the existing Router that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Router to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.8.1/docs/resources/router upcloud_router} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RouterConfig
    */
    constructor(scope: Construct, id: string, config: RouterConfig);
    get attachedNetworks(): string[];
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get type(): string;
    private _staticRoute;
    get staticRoute(): RouterStaticRouteList;
    putStaticRoute(value: RouterStaticRoute[] | cdktf.IResolvable): void;
    resetStaticRoute(): void;
    get staticRouteInput(): cdktf.IResolvable | RouterStaticRoute[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
